#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-data
version:              0.9.2.0
visibility:           public
id:                   generic-data-0.9.2.0-DBn5MUVniC2Jz9xtBoXCJa
key:                  generic-data-0.9.2.0-DBn5MUVniC2Jz9xtBoXCJa
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  fe2a784251c8c8dd634b35793c2090ef
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-8.10.5/site-local/generic-data-0.9.2.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/generic-data-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/generic-data-0.9.2.0
hs-libraries:         HSgeneric-data-0.9.2.0-DBn5MUVniC2Jz9xtBoXCJa
depends:
    ap-normalize-0.1.0.1-JmHVw5TOHGaBHo5q2Wmb1Y base-4.14.2.0
    base-orphans-0.8.4-B4zsXTdczgN9mmNUwgnmE3
    contravariant-1.5.3-KWoYE9wiUjmElzHNq2wj10 ghc-boot-th-8.10.5
    show-combinators-0.2.0.0-8uDgSiHZtc0BQAKnASEisS

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

